summaryrefslogtreecommitdiffstats
path: root/chrome/browser/net/dns_probe_job.h
diff options
context:
space:
mode:
authorttuttle@chromium.org <ttuttle@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-11-01 17:37:45 +0000
committerttuttle@chromium.org <ttuttle@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-11-01 17:37:45 +0000
commit42af17eaa9447b313098eca6fd5d018934cd0bbd (patch)
treead4f7b7df82b71d3320c4930349352342d24b1e6 /chrome/browser/net/dns_probe_job.h
parentd6fecb2ceb6d42aec716da5d34f3b5f992f91a6e (diff)
downloadchromium_src-42af17eaa9447b313098eca6fd5d018934cd0bbd.zip
chromium_src-42af17eaa9447b313098eca6fd5d018934cd0bbd.tar.gz
chromium_src-42af17eaa9447b313098eca6fd5d018934cd0bbd.tar.bz2
DnsProbeJob: Start fleshing things out.
BUG=156415 TEST=updates accompanying unittests; they still pass Review URL: https://chromiumcodereview.appspot.com/11264044 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@165419 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/net/dns_probe_job.h')
-rw-r--r--chrome/browser/net/dns_probe_job.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/chrome/browser/net/dns_probe_job.h b/chrome/browser/net/dns_probe_job.h
index 462ec46..cbed207 100644
--- a/chrome/browser/net/dns_probe_job.h
+++ b/chrome/browser/net/dns_probe_job.h
@@ -20,12 +20,13 @@ namespace chrome_browser_net {
class DnsProbeJob {
public:
enum Result {
- DNS_UNKNOWN,
- DNS_WORKING, // Server responds with correct answers.
+ SERVERS_UNKNOWN,
+ SERVERS_CORRECT, // Server responds with correct answers.
+ SERVERS_INCORRECT, // Server responds with success but incorrect answer.
// TODO(ttuttle): Do we want an "unreliable" result, for e.g. servers that
// lie about NXDOMAIN?
- DNS_BROKEN, // Server responds with errors.
- DNS_UNREACHABLE, // Server doesn't respond (or never got our packets)
+ SERVERS_FAILING, // Server responds with errors.
+ SERVERS_UNREACHABLE, // Server doesn't respond (or never got our packets)
};
typedef base::Callback<void(DnsProbeJob* job, Result result)> CallbackType;